@@ -35,7 +35,7 @@ def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit:
     :param pname: 库名
     :param module: 待引入的模块名，可缺省
     :param real_name: 用于 pip3 install 的名字
-    :param not_exit: 是否为真实包名
+    :param not_exit: 安装后不退出
     :return: 库或模块的地址
     """
     try:
@@ -55,7 +55,7 @@ def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit:
             if not_exit:
                 exec(f'from {pname} import {module}' if module else f"import {pname}")
             else:
-                exit(-1)
+                exit(0)
         else:
             exit(-1)
     finally:
